/* 2- Hasta el momento en todos los casos se asumi que los archivos fuente y de cabecera residen en el mismo directorio y que tambin los archivos generados (objetos y binario ejecutable) se ubicarn all. Sin embargo, a medida que un proyecto crece en cuanto a cantidad de archivos, se hace necesario organizarlos en subdirectorios. En un proyecto tpico podemos encontrar: src/ Contiene los archivos fuente (.c). include/ Contiene los archivos de cabecera (.h). bin/ Contiene el binario ejecutable generado. Tomando como caso el mismo proyecto que en el problema anterior, se muestra el archivo makefile utilizando la estructura de subdirectorios descripta. */

Makefile
	CC=gcc
	CFLAGS=-Wall -ansi -pedantic

	SRC_DIR=src
	INCLUDE_DIR=include
	BIN_DIR=bin

	VPATH=$(SRC_DIR)
	ejemplo: main.o conversion.o impresion.o
	$(CC) -o ejemplo main.o conversion.o impresion.o
	rm *.o
	mv ejemplo $(BIN_DIR)

	.c.o:
	$(CC) $(CFLAGS) -I$(INCLUDE_DIR) $< c

	clean:
	rm $(BIN_DIR)/ejemplo

/* La forma que tenemos de indicarle a make dnde buscar los archivos de dependencias (.c) es utilizar la macro VPATH. En nuestro caso, VPATH toma el valor src (o sea que los archivos fuente .c debern buscarse en el subdirectorio src/). Adems, tambin es necesario indicar al compilador dnde buscar los archivos de cabecera (ya que ahora no se encuentran en el mismo directorio que los archivos fuente, sino en el subdirectorio include/). Para ese fin se define la macro INCLUDE_DIR y se la utiliza con la opcin -I del compilador. Por ltimo, el binario ejecutable generado (ejemplo) se mueve al subdirectorio bin/ usando el comando mv y todos los archivos objeto generados se eliminan (esto suele ser una prctica habitual cuando se hace un lanzamiento del proyecto, ya que el usuario final no necesita la existencia de los archivos objeto). */

/* En este caso, una aplicacin solicita al usuario dos valores enteros: Base y exponente, y muestra en pantalla el resultado baseexponente. La operacin se realiza llamando a la funcin potencia() en el archivo my_math.c. Por su parte, esta funcin llama a pow(), que se encuentra implementada en la biblioteca matemtica estndar de C (libm). El grafo de dependencias es el siguiente:*/

main.c

#include <stdio.h>
#include "my_math.h"

int main()
{
	int base, exponente;

	printf("Ingrese la base: ");
	scanf("%d", &base);
	printf("Ingrese el exponente: ");
	scanf("%d", &exponente);

	printf("%d elevado a la %d = %d\n", base, exponente, potencia(base,exponente));

	return 0;
}
my_math.h

/* Prototipo */
int potencia(int base, int exponente);

my_math.c
#include <math.h>
{
	return (int)pow(base,exponente);
}

Makefile

CC=gcc
CFLAGS=-Wall -ansi -pedantic
LIBS=-lm

ejemplo: main.o my_math.o
$(CC) $(LIBS) -o ejemplo main.o my_math.o

math.o: math.c
$(CC) $(CFLAGS) c math.c

clean:
rm *.o ejemplo

/* En este programa se hace uso de una biblioteca externa (libm), en la que se encuentra la implementacin de la funcin pow(). Para indicar al compilador que el binario ejecutable debe enlazarse contra una biblioteca externa, se utiliza la opcin -l. Adems, se debe aadir el nombre de la biblioteca en cuestin, para lo cual se toma el nombre de ella y se quita el prefijo lib. Para el caso de libm, debe usarse: -lm. Para que esto quede ms claro, en el archivo makefile se defini la macro: LIBS=-lm */